Build the Forest in Python
==========================

.. image:: https://github.com/shunsvineyard/forest-python/actions/workflows/testing.yml/badge.svg
    :target: https://github.com/shunsvineyard/forest-python/actions/workflows/testing.yml

.. image:: https://github.com/shunsvineyard/forest-python/actions/workflows/linting.yml/badge.svg
    :target: https://github.com/shunsvineyard/forest-python/actions/workflows/linting.yml

.. image:: https://codecov.io/gh/shunsvineyard/forest-python/branch/main/graph/badge.svg?token=THWHJOY7EQ
    :target: https://codecov.io/gh/shunsvineyard/forest-python

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black


The *Build the Forest in Python* project is the repository for the `Build the Forest Series`_.
This project provides several tree data structure implementation, and is mainly for educative
and informative purposes.

.. _`Build the Forest Series`: https://shunsvineyard.info/build-the-forest-series/


Requirements
------------
``Python 3.9`` or newer is required.


Installation
------------
There are a few ways to install ``forest-python``.

- Install the latest release from PyPI

.. code-block:: bash

    pip install forest-python

- Install from Github

.. code-block:: bash

    git clone https://github.com/shunsvineyard/forest-python.git
    cd forest-python
    pip install -r requirements.txt
